# coding:utf-8
import datetime
from src.mf_driver import MFDriver
from src.utils.colors import Colors


class AttendanceManager(object):

    def __init__(self):
        self.mf_driver = MFDriver()
        self.driver = self.mf_driver.driver

    def login(self):
        return self.mf_driver.login()

    def clock_in(self):
        if self.driver.current_url != self.mf_driver.MYPAGE_URL:
            print("Please login.")

        self.driver.find_element_by_class_name(
            "attendance-card-time-stamp-clock-in"
        ).click()
        print("CLOCK " + Colors.get_colored(Colors.BOLD, "IN") + " TIME: "
              + self.current_time())
        Colors.print(Colors.GREEN, "DAKOKU successful. Good luck!")

    def clock_out(self):
        if self.driver.current_url != self.mf_driver.MYPAGE_URL:
            print("Please login.")

        self.driver.find_element_by_class_name(
            "attendance-card-time-stamp-clock-out"
        ).click()
        print("CLOCK " + Colors.get_colored(Colors.BOLD, "OUT") + " TIME: "
              + self.current_time())
        Colors.print(Colors.GREEN, "DAKOKU successful. Good job today!")

    def current_time(self):
        return str(datetime.datetime.now()).split('.')[0]

    def exit(self):
        self.driver.close()



# coding:utf-8
class Colors(object):
    RED = '\033[31m'
    GREEN = '\033[32m'
    YELLOW = '\033[33m'
    BLUE = '\033[34m'
    PURPLE = '\033[35m'
    CYAN = '\033[36m'
    WHITE = '\033[37m'
    BOLD = '\033[1m'
    END = '\033[0m'

    @classmethod
    def get_colored(cls, color, text):
        return color + text + Colors.END

    @classmethod
    def print(cls, color, text):
        print(Colors.get_colored(color, text))



# coding:utf-8
import os
import pickle
import getpass

from src.utils.colors import Colors
from selenium import webdriver
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC
from selenium.common.exceptions import TimeoutException
from selenium.webdriver.chrome.options import Options


class MFDriver(object):
    TIMEOUT = 3
    COOKIE_PATH = os.environ['HOME'] + '/.local/share/dakoker'
    ROOT_URL = "https://attendance.moneyforward.com"
    LOGIN_URL = ROOT_URL + "/employee_session/new"
    MYPAGE_URL = ROOT_URL + "/my_page"

    def __init__(self):
        self.cookies = self.load_cookies()

        options = Options()
        options.headless = True
        self.driver = webdriver.Chrome(chrome_options=options)

    def login(self):
        if self.cookies:
            self.driver.get(self.ROOT_URL)
            for cookie in self.cookies:
                self.driver.add_cookie(cookie)
            self.driver.get(self.MYPAGE_URL)
            return self.check_login()
        else:
            self.driver.get(self.LOGIN_URL)
            return self.stdin_login()

    def stdin_login(self):
        company_id = input("company ID: ")
        user_id = input("user ID or your email address: ")
        user_pass = getpass.getpass("password: ")

        self.driver.find_element_by_id(
            "employee_session_form_office_account_name"
        ).send_keys(company_id)
        self.driver.find_element_by_id(
            "employee_session_form_account_name_or_email"
        ).send_keys(user_id)
        self.driver.find_element_by_id(
            "employee_session_form_password"
        ).send_keys(user_pass)

        self.driver.find_element_by_class_name(
            "attendance-before-login-card-button"
        ).click()

        return self.check_login()

    def check_login(self):
        try:
            WebDriverWait(self.driver, self.TIMEOUT).until(
                EC.presence_of_element_located(
                    (By.CLASS_NAME, "attendance-card-title")
                )
            )
            self.save_cookie()
            print("Login successful.")

            return True
        except TimeoutException:
            if self.driver.find_elements(By.CLASS_NAME, "is-error") != 0:
                Colors.print(
                    Colors.RED,
                    "Login Failed: company ID, user ID or password is wrong."
                )
            else:
                Colors.print(Colors.RED, "Login Timeout")

            return False

    def load_cookies(self):
        if os.path.exists(self.COOKIE_PATH + "/cookie.pkl"):
            print("cookie loading...")
            with open(self.COOKIE_PATH + "/cookie.pkl", "rb") as f:
                return pickle.load(f)

        return None

    def save_cookie(self):
        if not os.path.exists(self.COOKIE_PATH):
            os.makedirs(self.COOKIE_PATH)
        pickle.dump(self.driver.get_cookies(),
                    open(self.COOKIE_PATH + "/cookie.pkl", "wb"))



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['src', 'src.utils']

package_data = \
{'': ['*']}

install_requires = \
['beautifulsoup4>=4.9.1,<5.0.0',
 'bs4>=0.0.1,<0.0.2',
 'fire>=0.3.1,<0.4.0',
 'ipython>=7.15.0,<8.0.0',
 'pendulum>=2.1.0,<3.0.0',
 'selenium>=3.141.0,<4.0.0',
 'slackbot>=0.5.6,<0.6.0']

entry_points = \
{'console_scripts': ['dakoker = src.dakoker:main']}

setup_kwargs = {
    'name': 'dakoker',
    'version': '0.1.11',
    'description': '',
    'long_description': '[![PyPI](https://img.shields.io/pypi/v/dakoker.svg)](https://pypi.python.org/pypi/dakoker)\n\nMF-Dakoker\n=======\n\n[MFクラウド勤怠](https://biz.moneyforward.com/attendance)利用者向けに作った打刻・勤怠状況確認ツールです。\n\n主な機能\n- MFクラウド勤怠へのログイン, 出勤・退勤の打刻\n\n実装予定機能\n- 休憩時間の打刻\n- 二重打刻の防止機能\n- 過去・当日の勤怠状況の確認(打刻日時)\n\n動作環境\n- Python 3.8以降\n\n## How to Install\n`pip3 install dakoker`\n\n## Usage\n\n- 出勤\n  - `dakoker start`\n- 退勤\n  - `dakoker stop`\n\n### 初回利用時\nログインのため、以下の情報を入力します\n(2回目以降は前回ログイン時のcookieを読み込み自動ログインします)\n- 企業ID\n- ユーザーID もしくは登録メールアドレス\n- パスワード\n\n![初回ログイン時](https://gyazo.com/e0657a3eecfc6a486a469a0cebd98db1.png)\n',
    'author': 'nixiesquid',
    'author_email': 'audu817@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
